@@ -4,9 +4,7 @@
  * GChemPaint arrows plugin
  * arrowtool.cc 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -66,7 +64,7 @@ static void on_default (gcpArrowToolDlg* dlg)
 	dlg->OnDefault ();
 }
 
-gcpArrowToolDlg::gcpArrowToolDlg (gcpApplication* App, bool FullHeads): gcpDialog(App, DATADIR"/gchempaint/ui/arrowtool.glade", "arrowtool")
+gcpArrowToolDlg::gcpArrowToolDlg (gcpApplication* App, bool FullHeads): gcpDialog(App, PKGDATADIR"/ui/arrowtool.glade", "arrowtool")
 {
 	GtkTable *table = GTK_TABLE (glade_xml_get_widget (xml, "heads_table"));
 	GnomeCanvas *canvas = GNOME_CANVAS (gnome_canvas_new_aa ());
