@@ -4,9 +4,7 @@
  * GChemPaint templates plugin
  * plugin.cc 
  *
- * Copyright (C) 2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -29,10 +27,10 @@
 #include "lib/application.h"
 #include "templatetool.h"
 #include "templatetree.h"
-#include <mcheck.h>
 #include <sys/stat.h>
 
 gcpTemplatesPlugin plugin;
+extern set<xmlDocPtr> docs;
 
 gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 {
@@ -41,14 +39,15 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 	xmlNodePtr node;
 	const char *name;
 	char *path;
-	GDir* dir = g_dir_open (DATADIR"/gchempaint/templates", 0, NULL);
+	GDir* dir = g_dir_open (PKGDATADIR"/templates", 0, NULL);
 	xmlIndentTreeOutput = true;
 	xmlKeepBlanksDefault (0);
 	if (dir) {
-		while (name = g_dir_read_name (dir)) {
+		while ((name = g_dir_read_name (dir))) {
 			if (strcmp (name + strlen (name) - 4, ".xml")) continue;
-			name = g_strconcat (DATADIR"/gchempaint/templates/", name, NULL);
+			name = g_strconcat (PKGDATADIR"/templates/", name, NULL);
 			doc = xmlParseFile (name);
+			docs.insert (doc);
 			node = doc->children;
 			if (!strcmp ((char*)node->name, "templates")) ParseNodes (node->children, false);
 			g_free ((void*) name);
@@ -59,11 +58,12 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 	dir = g_dir_open (path, 0, NULL);
 	if (dir) {
 		bool is_user_templates;
-		while (name = g_dir_read_name (dir)) {
+		while ((name = g_dir_read_name (dir))) {
 			if (strcmp (name + strlen (name) - 4, ".xml")) continue;
 			is_user_templates = !strcmp (name, "templates.xml");
 			name = g_strconcat (path, "/", name, NULL);
 			doc = xmlParseFile (name);
+			docs.insert (doc);
 			if (is_user_templates)
 				user_templates = doc;
 			node = doc->children;
@@ -86,11 +86,20 @@ gcpTemplatesPlugin::gcpTemplatesPlugin(): gcpPlugin()
 
 gcpTemplatesPlugin::~gcpTemplatesPlugin()
 {
+	set<xmlDocPtr>::iterator i, iend = docs.end ();
+	for (i = docs.begin (); i != iend; i++)
+		xmlFreeDoc (*i);
+	docs.clear ();
+	map<string, gcpTemplate*>::iterator j, jend = Templates.end ();
+	for (j = Templates.begin (); j != jend; j++)
+		delete (*j).second;
+	Templates.clear ();
+	TempbyName.clear ();
 }
 
 void gcpTemplatesPlugin::Populate (gcpApplication* App)
 {
-	App->AddUI (DATADIR"/gchempaint/ui/templates.xml");
+	App->AddUI (PKGDATADIR"/ui/templates.xml");
 	new gcpTemplateTool (App);
 	new gcpTemplateTree (App);
 }
